# ICE TEMPLE

__title__ = 'bzp'
__description__ = 'Manager for bz2 pickle files'
__url__ = 'https://github.com/ideascup/bzp/'
__version__ = '1.1.0'
__build__ = 0x010100
__author__ = 'Dmitriy Pleshevskiy'
__author_email__ = 'dmitriy@ideascup.me'
__license__ = 'MIT'
__copyright__ = 'Copyright 2018 Dmitriy Pleshevskiy'
